/* ----------------------------------------------------------------
 *
 * fits.h
 *
 * Project: Andor  (OCIW, Pasadena, CA)
 *
 * Christoph C. Birk (birk@carnegiescience.edu)
 *
 * ---------------------------------------------------------------- */

#ifndef INCLUDE_FITS_H
#define INCLUDE_FITS_H 

/* DEFINEs -------------------------------------------------------- */

#ifdef IS_FITS_C
#define EXT_FITS
#else
#define EXT_FITS extern
#endif

#define FITS_VERSION  "0.012"

#define FITSRECORD    80                      /* FITS record length */
#define FITSBLOCK     (36*FITSRECORD)         /* FITS block length */
#define FITSNBLKS     1                       /* # of FITS blocks */
#define FITSLINES     (FITSNBLKS*36)          /* # of header-lines */
#define FITSLEN       (FITSLINES*FITSRECORD)  /* length of FITS-header */

#define MAX_FILENUM   9999

/* INCLUDEs ------------------------------------------------------- */

#include <time.h>                      /* time_t */

#ifdef MACOSX
#include <sys/types.h>
#endif

/* TYPEDEFs ------------------------------------------------------- */
 
typedef struct fitskey_tag {
  int   id;
  char* keyword;
} FITSKey;

typedef struct system_parameters_tag { // IDEA use 'Guider' 
  /* camera */
  char   instrument[64],serial[32];    // IDEA other andor stuff
  int    dimx,dimy;
  float  pixscale;
  float  pa;                           /* instrument vs. North */
  /* observing */
  double start_int,stop_int;
  int    run;
  u_int  seqNumber;                    // IDEA rolling ave
  float  exptime;
  int    binning;
  char   prefix[16];
  float  temp_ccd;
  char   origin[64];
  /* FITS */
  int    bzero;
  char   datapath[512];
  char   filename[64];
  char   version[64];
} FITSpars;

/* function prototype(s) ------------------------------------------ */ 

EXT_FITS int      fits_save    (u_short*,FITSpars*);

/* ---------------------------------------------------------------- */

enum fits_headers {
  F_SIMPLE,F_BITPIX,F_NAXIS,F_NAXIS1,F_NAXIS2,   /* mandatory */
 
  F_BSCALE,F_BZERO,F_BUNIT,                      /* data */
 
  F_ORIGIN,
  F_INSTRUMENT,
  F_SCALE,          
 
  F_DATE_OBS,
  F_UT_DATE,F_UT_TIME,F_UT_END,F_LC_TIME,        /* time */
  F_EPOCH,
 
  F_FILENAME,
  F_EXPTIME,
  F_SEQN,
  F_BINNING,

  F_COMMENT,

  F_TEMP_CCD,

  F_SOFTWARE,                          /* misc. */
  F_FITS,                    /* must be the last one before F_END */
 
  F_END = FITSLINES-1                            /* last entry */
};

/* ---------------------------------------------------------------- */

#if defined(IS_FITS_C) || defined(IS_QLTOOL_C)

static FITSKey fitskeys[] = {
  { F_SIMPLE,    "SIMPLE  " },         /* mandatory keywords */
  { F_BITPIX,    "BITPIX  " },
  { F_NAXIS,     "NAXIS   " },
  { F_NAXIS1,    "NAXIS1  " },
  { F_NAXIS2,    "NAXIS2  " },
  { F_BSCALE,    "BSCALE  " },         /* data scaling */
  { F_BZERO,     "BZERO   " },
  { F_BUNIT,     "BUNIT   " },
 
  { F_ORIGIN,    "ORIGIN" },           /* origin */
  { F_INSTRUMENT,"INSTRUME" },   
  { F_SCALE,     "SCALE" },
 
  { F_DATE_OBS,  "DATE-OBS" },         /* time */
  { F_UT_DATE,   "UT-DATE" },
  { F_UT_TIME,   "UT-TIME" },
  { F_UT_END,    "UT-END" },
  { F_LC_TIME,   "LC-TIME" },
  { F_EPOCH,     "EPOCH" },

  { F_FILENAME,  "FILENAME" },

  { F_EXPTIME,   "EXPTIME" },
  { F_SEQN,      "SEQ-NUM" },
  { F_BINNING,   "BINNING" },

  { F_COMMENT,   "COMMENT" },

  { F_TEMP_CCD,  "TEMPCCD" },

  { F_SOFTWARE,  "SOFTWARE" },
  { F_FITS,      "FITSVERS" },
 
  { F_END,       "END" },
 
  { -1,"" }
};
 
#endif /* IS_FITS_C */

/* ---------------------------------------------------------------- */

#endif  /* INCLUDE_FITS_H */

/* ---------------------------------------------------------------- */
/* ---------------------------------------------------------------- */
/* ---------------------------------------------------------------- */

